pub enum EventKey {
Key(Key),
Mouse(MouseButton),
}Expand description
A convenience type that combines Key and MouseButton. Can often be used for specifying controls where only press/release plays a role.
Variants
Key(Key)
Mouse(MouseButton)
Implementations
Sourceimpl EventKey
impl EventKey
Sourcepub fn is_pressed(self, window: &Window) -> bool
pub fn is_pressed(self, window: &Window) -> bool
Check whether the key is pressed.
Sourcepub fn is_event_press(self, event: &Event) -> bool
pub fn is_event_press(self, event: &Event) -> bool
Check whether the event corresponds to the press of the key.
Sourcepub fn is_event_release(self, event: &Event) -> bool
pub fn is_event_release(self, event: &Event) -> bool
Check whether the event corresponds to the release of the key.