pub struct CameraTorus<T: Float> {
pub center: PositionTorus<T>,
pub fov: T,
pub rotation: Angle<T>,
}Expand description
A camera that exists on a torus space.
Use the project method to get a normalized position of objects relative to the camera.
Fields
center: PositionTorus<T>fov: Trotation: Angle<T>Implementations
Sourceimpl<T: Float> CameraTorus<T>
impl<T: Float> CameraTorus<T>
Sourcepub fn new(fov: T, world_size: vec2<T>) -> Self
pub fn new(fov: T, world_size: vec2<T>) -> Self
Construct a new camera on a torus with the given size.
Sourcepub fn project(&self, position: PositionTorus<T>) -> vec2<T>
pub fn project(&self, position: PositionTorus<T>) -> vec2<T>
Project a world position to a position relative to the camera. The resulting position can be used to render the object.
Sourcepub fn project_f32(&self, position: PositionTorus<T>) -> vec2<f32>
pub fn project_f32(&self, position: PositionTorus<T>) -> vec2<f32>
Project a world position to a position relative to the camera. The resulting position can be used to render the object.