pub struct PositionTorus<T> { /* private fields */ }Expand description
A position on a torus.
Implementations
Sourceimpl<T: Num> PositionTorus<T>
impl<T: Num> PositionTorus<T>
Sourcepub fn from_world(pos: vec2<T>, world_size: vec2<T>) -> Self
pub fn from_world(pos: vec2<T>, world_size: vec2<T>) -> Self
Normalize a position in the world to a torus.
Sourcepub fn random(rng: &mut impl Rng, world_size: vec2<T>) -> Self
pub fn random(rng: &mut impl Rng, world_size: vec2<T>) -> Self
Get a random position on a torus of a given size.
pub fn to_world(self) -> vec2<T>
pub fn world_size(self) -> vec2<T>
Sourceimpl<T: Float> PositionTorus<T>
impl<T: Float> PositionTorus<T>